==> haskell-binary-parser-0.5.5-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-binary-parser.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: binary-parser
version: 0.5.5
id: binary-parser-0.5.5-EaBFSBxb0XEJII5ytVbu3
key: binary-parser-0.5.5-EaBFSBxb0XEJII5ytVbu3
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/binary-parser
synopsis: A highly-efficient but limited parser API specialised for bytestrings
category: Parser, Binary
author: Nikita Volkov <nikita.y.volkov@mail.ru>
exposed: True
indefinite: False
exposed-modules:
    BinaryParser
hidden-modules: BinaryParser.Prelude
abi: 458aa6a4bc1f7fddb8f96d38356050bc
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/binary-parser-0.5.5
library-dirs: /usr/lib/ghc-8.2.2/site-local/binary-parser-0.5.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/binary-parser-0.5.5
hs-libraries: HSbinary-parser-0.5.5-EaBFSBxb0XEJII5ytVbu3
depends:
    bytestring-0.10.8.2 text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj
    mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH transformers-0.5.2.0
    base-prelude-1.2.0.1-Jp4fn0lH8rP2DHoIPVF2qm base-4.10.1.0
abi-depends: bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=a1f89647d7228db4bf59b7aaec52e888
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             base-prelude-1.2.0.1-Jp4fn0lH8rP2DHoIPVF2qm=3e78347d5a15e89f4fb1084b18368182
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
haddock-interfaces: /usr/share/doc/haskell-binary-parser/html/binary-parser.haddock
haddock-html: /usr/share/doc/haskell-binary-parser/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-binary-parser-0.5.5-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-binary-parser.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: binary-parser
version: 0.5.5
id: binary-parser-0.5.5-LHus2c1Y1qfLYVfWFuYwat
key: binary-parser-0.5.5-LHus2c1Y1qfLYVfWFuYwat
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/binary-parser
synopsis: A highly-efficient but limited parser API specialised for bytestrings
category: Parser, Binary
author: Nikita Volkov <nikita.y.volkov@mail.ru>
exposed: True
indefinite: False
exposed-modules:
    BinaryParser
hidden-modules: BinaryParser.Prelude
abi: 7c1411dbaa3edb73fd52246c81a16f1c
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/binary-parser-0.5.5
library-dirs: /usr/lib/ghc-8.2.2/site-local/binary-parser-0.5.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/binary-parser-0.5.5
hs-libraries: HSbinary-parser-0.5.5-LHus2c1Y1qfLYVfWFuYwat
depends:
    bytestring-0.10.8.2 text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz
    mtl-2.2.2-8XubxMJDT8QLsstvlNotkc transformers-0.5.2.0
    base-prelude-1.2.0.1-Jp4fn0lH8rP2DHoIPVF2qm base-4.10.1.0
abi-depends: bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             base-prelude-1.2.0.1-Jp4fn0lH8rP2DHoIPVF2qm=3e78347d5a15e89f4fb1084b18368182
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
haddock-interfaces: /usr/share/doc/haskell-binary-parser/html/binary-parser.haddock
haddock-html: /usr/share/doc/haskell-binary-parser/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
